@@ -33,9 +33,8 @@ public class testprovider {
     // Check the response.
     if (resp.generatedFault ()) {
       Fault fault = resp.getFault ();
-      System.out.println ("Ouch, the call failed: ");
-      System.out.println ("  Fault Code   = " + fault.getFaultCode ());  
-      System.out.println ("  Fault String = " + fault.getFaultString ());
+
+      System.err.println("Generated fault: " + fault);
     } else {
       Parameter result = resp.getReturnValue ();
       System.out.println ( "Done" );
