@@ -105,6 +105,7 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
   private static LongDeserializer longDeser =  new LongDeserializer();
   private static ShortDeserializer shortDeser =  new ShortDeserializer();
   private static ByteDeserializer byteDeser =  new ByteDeserializer();
+  private static HexDeserializer hexDeser =  new HexDeserializer();
 
   private static QNameSerializer qNameSer = new QNameSerializer();
   private static ParameterSerializer paramSer = new ParameterSerializer();
@@ -144,6 +145,7 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     Constants.short1999QName,
     Constants.byte1999QName,
     Constants.byte1999QName,
+    Constants.hex1999QName,
     Constants.qName1999QName,
     Constants.date1999QName,
     Constants.timeInst1999QName,
@@ -171,6 +173,7 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     Constants.short2000QName,
     Constants.byte2000QName,
     Constants.byte2000QName,
+    Constants.hex2000QName,
     Constants.qName2000QName,
     Constants.date2000QName,
     Constants.timeInst2000QName,
@@ -198,6 +201,7 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     Constants.short2001QName,
     Constants.byte2001QName,
     Constants.byte2001QName,
+    Constants.hex2001QName,
     Constants.qName2001QName,
     Constants.date2001QName,
     Constants.timeInst2001QName,
@@ -225,6 +229,7 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     short.class,
     Byte.class,
     byte.class,
+    Hex.class,
     QName.class,
     GregorianCalendar.class,
     Date.class,
@@ -248,15 +253,22 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
       throws IllegalArgumentException, IOException {
       nsStack.pushScope();
 
-      SoapEncUtils.generateStructureHeader(inScopeEncStyle,
-                                           javaType,
-                                           context,
-                                           sink,
-                                           nsStack,
-                                           xjmr);
-
-      sink.write(Utils.cleanString(src.toString()) + "</" + context + '>');
-
+      if (src == null)
+      {
+        SoapEncUtils.generateNullStructure(inScopeEncStyle, javaType, context,
+                                           sink, nsStack, xjmr);
+      }
+      else
+      {
+        SoapEncUtils.generateStructureHeader(inScopeEncStyle,
+                                             javaType,
+                                             context,
+                                             sink,
+                                             nsStack,
+                                             xjmr);
+        
+        sink.write(Utils.cleanString(src.toString()) + "</" + context + '>');
+      }
       nsStack.popScope();
     }
   };
@@ -304,6 +316,7 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     ser,       // short
     ser,       // Byte
     ser,       // byte
+    ser,       // Hex
     qNameSer,  // QName
     calSer,    // GregorianCalendar
     dateSer,   // Date
@@ -331,6 +344,7 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     shortDeser,
     null,
     byteDeser,
+    hexDeser,
     qNameSer,
     calSer,
     dateSer,
@@ -411,6 +425,16 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     }
   }
 
+  /** Set the default encoding style.  If the query*() calls
+   * are invoked with a null encodingStyleURI parameter, we'll
+   * use this instead.
+   */
+  public void setDefaultEncodingStyle(String defEncStyle) {
+      super.setDefaultEncodingStyle(defEncStyle);
+      if (parent != null)
+	      parent.setDefaultEncodingStyle(defEncStyle);
+  }
+
   /**
    * Return the schemaURI that was used to create this registry
    * instance.
@@ -419,6 +443,14 @@ public class SOAPMappingRegistry extends XMLJavaMappingRegistry
     return schemaURI;
   }
 
+  /**
+   * Returns the "parent" registry, if there is one. Otherwise,
+   * returns null.
+   */
+  public SOAPMappingRegistry getParent () {
+    return parent;
+  }
+
   /**
    * Initialize myself with all the built-in default stuff. If schemaURI
    * is not recognized, defaults to 2001 schema URI.
