@@ -461,7 +461,7 @@ public class RPCMessage implements Serializer {
                                                    fault, params, null,
                                                    declMsgEncStyle, ctx))
                      : (RPCMessage)new Call(fullTargetObjectURI, methodName,
-                                            params, null, declMsgEncStyle, ctx);
+                                            params, null, actualMsgEncStyle, ctx);
 
     if (msg instanceof Call) {
       ((Call)msg).setSOAPMappingRegistry(smr);
