@@ -362,6 +362,13 @@ public class SOAPContext {
             parts.addBodyPart(part, index);
     }
 
+    /**
+     * Remove a body part.
+     */
+    public void removeBodyPart(MimeBodyPart part) throws MessagingException {
+      parts.removeBodyPart(part);
+    }
+
     /**
      * Adds the root BodyPart. Add it in the first position, create a
      * unique Content ID and set the "start" Content-Type header modifier
