@@ -72,6 +72,7 @@ import org.apache.soap.util.xml.*;
  * This class represents the deployment information about a SOAP service.
  *
  * @author Sanjiva Weerawarana (sanjiva@watson.ibm.com)
+ * @author Matthew J. Duftler (duftler@us.ibm.com)
  */
 public class DeploymentDescriptor implements Serializable {
   // types of services
@@ -354,11 +355,11 @@ public class DeploymentDescriptor implements Serializable {
                   "\" static=\"" + (isStatic ? "true" : "false") + "\"/>");
     } else if (pt == DeploymentDescriptor.PROVIDER_SCRIPT_FILE ||
                pt == DeploymentDescriptor.PROVIDER_SCRIPT_STRING ) {
-      pw.print ("    <isd:script language=\"" + scriptLanguage);
+      pw.print ("    <isd:script language=\"" + scriptLanguage + "\"");
       if (pt == DeploymentDescriptor.PROVIDER_SCRIPT_FILE) {
         pw.println (" source=\"" + scriptFilenameOrString + "\"/>");
       } else {
-        pw.println ("\">");
+        pw.println (">");
         pw.println ("      <![CDATA[");
         pw.println (scriptFilenameOrString);
         pw.println ("      ]]>");
@@ -399,21 +400,33 @@ public class DeploymentDescriptor implements Serializable {
 
       for (int i = 0; i < mappings.length; i++) {
         TypeMapping tm = mappings[i];
-        pw.print ("    <isd:map encodingStyle=\"" + tm.encodingStyle +
-                  "\" xmlns:x=\"" + tm.elementType.getNamespaceURI () +
-                  "\" qname=\"x:" + tm.elementType.getLocalPart () + "\"");
 
-	if (tm.javaType != null) {
+        pw.print ("    <isd:map");
+
+        if (tm.encodingStyle != null) {
+          pw.print (" encodingStyle=\"" + tm.encodingStyle +"\"");
+        }
+
+        if (tm.elementType != null) {
+          pw.print (" xmlns:x=\"" + tm.elementType.getNamespaceURI () +
+                    "\" qname=\"x:" + tm.elementType.getLocalPart () + "\"");
+        }
+
+        if (tm.javaType != null) {
           pw.print (" javaType=\"" + tm.javaType + "\"");
         }
+
         if (tm.xml2JavaClassName != null) {
           pw.print (" xml2JavaClassName=\"" + tm.xml2JavaClassName + "\"");
         }
+
         if (tm.java2XMLClassName != null) {
           pw.print (" java2XMLClassName=\"" + tm.java2XMLClassName + "\"");
         }
+
         pw.println ("/>");
       }
+
       pw.println ("  </isd:mappings>");
     }
 
@@ -516,6 +529,25 @@ public class DeploymentDescriptor implements Serializable {
     int scope = -1;
     String[] methods;
 
+    Element saved_E = e ;
+    nl = e.getElementsByTagNameNS(Constants.NS_URI_XML_SOAP_DEPLOYMENT,
+                                  "option" );
+    for ( int i = 0 ; nl != null && i < nl.getLength() ; i++ ) {
+      String  key, value ;
+
+      e = (Element) nl.item(i);
+      key   = DOMUtils.getAttribute( e, "key" );
+      value = DOMUtils.getAttribute( e, "value" );
+
+      if ( key == null || key.equals("") )
+        throw new IllegalArgumentException("Missing 'key' attribute on " +
+                                           "'option' element in deployment " +
+                                           "desriptor" );
+      if ( dd.props == null ) dd.props = new Hashtable();
+      dd.props.put( key, value );
+    }
+    e = saved_E ;
+
     if (typeStr.equals ("java")) {
       dd.setProviderType (DeploymentDescriptor.PROVIDER_JAVA);
       nl = e.getElementsByTagNameNS (Constants.NS_URI_XML_SOAP_DEPLOYMENT,
@@ -571,26 +603,7 @@ public class DeploymentDescriptor implements Serializable {
       dd.setProviderType (DeploymentDescriptor.PROVIDER_USER_DEFINED);
       dd.setServiceClass (typeStr);
 
-      Element saved_E = e ;
-      nl = e.getElementsByTagNameNS(Constants.NS_URI_XML_SOAP_DEPLOYMENT,
-                                    "option" );
-      for ( int i = 0 ; nl != null && i < nl.getLength() ; i++ ) {
-        String  key, value ;
-
-        e = (Element) nl.item(i);
-        key   = DOMUtils.getAttribute( e, "key" );
-        value = DOMUtils.getAttribute( e, "value" );
-
-        if ( key == null || key.equals("") )
-          throw new IllegalArgumentException("Missing 'key' attribute on " +
-                                             "'option' element in deployment " +
-                                             "desriptor" );
-        if ( dd.props == null ) dd.props = new Hashtable();
-        dd.props.put( key, value );
-      }
-
       // Support old 'java' tag
-      e = saved_E ;
       nl = e.getElementsByTagNameNS (Constants.NS_URI_XML_SOAP_DEPLOYMENT,
                                      "java");
       if ( nl != null ) {
@@ -670,8 +683,9 @@ public class DeploymentDescriptor implements Serializable {
     if (nl.getLength () == 1) {
       e = (Element) nl.item (0);
 
-      String className = e.getAttribute("defaultRegistryClass");
-      if (className != "") {
+      String className = DOMUtils.getAttribute(e, "defaultRegistryClass");
+
+      if (className != null) {
         dd.setDefaultSMRClass(className);
       }
 
@@ -683,14 +697,10 @@ public class DeploymentDescriptor implements Serializable {
         dd.setMappings (tms);
         for (int i = 0; i < nmaps; i++) {
           e = (Element) nl.item (i);
-          String qnameQname = DOMUtils.getAttribute (e, "qname");
-          int pos = qnameQname.indexOf (':');
-          String prefix = qnameQname.substring (0, pos);
-          String localPart = qnameQname.substring (pos+1);
-          String nsURI = DOMUtils.getNamespaceURIFromPrefix (e, prefix);
+          QName qname = DOMUtils.getQualifiedAttributeValue(e, "qname");
           tms[i] =
             new TypeMapping (DOMUtils.getAttribute (e, "encodingStyle"),
-                             new QName (nsURI, localPart),
+                             qname,
                              DOMUtils.getAttribute (e, "javaType"),
                              DOMUtils.getAttribute (e, "java2XMLClassName"),
                              DOMUtils.getAttribute (e, "xml2JavaClassName"));
@@ -732,8 +742,29 @@ public class DeploymentDescriptor implements Serializable {
       for (int i = 0; i < faultListener.length;
         lis.append(faultListener[i]), lis.append(" "), i++);
     lis.append("]");
+
+    StringBuffer opts = new StringBuffer();
+    if (props != null) 
+      opts.append( props.toString() );
+
     return header + body + "methods='" + methodsStrbuf + "', " +
-      "faultListener='" + lis + "', " + "mappings='" + mappings + "']";
+      "faultListener='" + lis + "', " + "mappings='" +
+      mappingsToString(mappings) + "'], " +
+      "opts='" + opts ;
+  }
+
+  private static String mappingsToString(TypeMapping[] mappings) {
+    if (mappings != null) {
+      StringBuffer strBuf = new StringBuffer();
+
+      for (int i = 0; i < mappings.length; i++) {
+        strBuf.append((i > 0 ? " " : "") + mappings[i]);
+      }
+
+      return strBuf.toString();
+    } else {
+      return null;
+    }
   }
 
   /**
